//Arduino Code: Lego Sorter

#inlude <Servo.h>;
Servo gripper;
#include <Wire.h>
#include "Adafruit_TCS34725.h"

//set all the variables needed

//constants that will be used when we call functions
int upDirection = 1;
int downDirection = -1;
int boxDirection = 1;
int blockDirection = -1;
int gripperOpening = 1;
int gripperClosing = -1;

//at the beginning I set all the variables to false to have no errors like “no value attributed”

bool moveRobot = false; //if true, the robot has to move vertically or horizontally; if false the robot doesn’t

bool gripperWorks = false;   //true when the gripper opens or grabs
bool grab; //true when the gripper has to close; false when it has to open
int pinGripper = 9;  //number of the pin to control the servomotor
int angleLow = 10; //angles have to be finetuned
int angleHigh = 120; //angles have to be finetuned
int delayGripper = 5;

bool moveGlobalToBox = false; //if true, the goal of the robot is to at the end to the box (contains the following sequence of movement up -> then horizontal towards boxes->finally down to the box); if false the goal of the robot is to go finally  to the block (contains the following sequence of movement up -> then horizontal towards blocks>finally down to the block)

bool moveVertical = false; //true when the robot has to move vertically
bool moveUp = false; //true when it moves upwards; false when it moves downwards

bool moveHorizontal = false; //true when the robot has to move horizontally
bool moveToBox = false; //true when it moves towards the boxes; false when it moves towards the //block

bool reached; //this variable will be used several times in the code; it will be the output of the function moveVerticalFunction and moveHorizontalFunction

bool moveBelt = false; //if true, the belt has to work till the next block is detected by the proximity sensor

bool firstCycle = true; //special things to do for the first cycle

/* Connect SCL to analog 5
Connect SDA to analog 4
Connect VDD to 3.3V DC
//color sensor

Connect GROUND to common ground */
/* Initialise with default values (int time = 2.4ms, gain = 1x) */
// Adafruit_TCS34725 tcs = Adafruit_TCS34725();
 
/* Initialise with specific int time and gain values */
Adafruit_TCS34725 tcs = Adafruit_TCS34725(TCS34725_INTEGRATIONTIME_700MS, TCS34725_GAIN_1X);
int limitColor = 1500; //value has to be fine tuned depending on the sensor and the blocks used

//set the array of 'limits'/boundaries
int distances[4] = {200, 320, 420}; //first value depends on where the belt is placed

//store the color of the current and following color with a number
int currentColor = -1; //1 = grey; 2 = red; 3 = green
//color of the following color
int followingColor; //1 = grey; 2 = red; 3 = green

//setup

//set all the pins

int pinTachoHor = 0;
int counterTachHor = 0;
int prevValTachHor = -1;
int valTachHor;
int treshholdTachHor = 0.5;
int numberOfTeethHor = 18;  //of the tachometer
int numberOfDetectionsPerCycleHor = 18*2;
int diameterHor = 4.2; //cm   pitchdiameter of the wheels for the horizontal movement
int maxCountTachHor;

 //tachometer vertical
int pinTachoVer = 1;
int counterTachVer = 0;
int prevValTachVer = -1;
int valTachVer;
int treshholdTachVer = 0.5;
//int numberOfTeethVer = 18;  //of the tachometer
int numberOfDetectionsPerCycleVer = 18*2;
//int diameterVer = 2.7; //cm    pitchdiameter of the wheels for the vertical movement
int maxCountInitVer = 36; //has to be finetuned (position of the rack at the beginning at the position LOW, number of rising/faling edges from when the rack is completely down)
int maxCountTachVer = 36; //to be fine tuned

 //pin proximity sensor
 int pinProximitySensor = 2;//ATTENTION PULL UP RESISTOR, for example pin 2

 int detectionProximity; //equal to ZERO if it detects an object

 //DC motors
int pinEnableVert = 3; //PWM
int pinInMotorVert1 = 4; //not PWM
int pinInMotorVert2 = 7; //not PWM
int pwmOutput = 255; //full power
int pinEnableHor = 5;
int pinInMotorHor1 = 8; //not PWM
int pinInMotorHor2 = 12; //not PWM
int pwmZero = 0; //to disable the H-bridge
int delayInitHor = 500; //milliseconds
int pwmSlow = 100; //has to be finetuned

//motor belt
int pinEnableBelt = 6;
int pinInMotorBelt1 = 10; //not PWM
int pinInMotorBelt2 = 11; //not PWM
int delayStopBelt = 900; //has to be finetuned
int delaySecondWorkBelt = 500; //has to be finetuned

//switches placed on the rack that will be enabled when the motor passes on
int pinSwitches = A3; //analog
//array values of the switches
//lower limit to be sure to detect the switch
int voltageSwitches[3] = {200, 500, 800}; //1024*ratio with ratio = 10kOhm/(resisitor+10kOhm); resisitors are equal to 39kOhm, 10 kOhm and 2.4kOhm
int valueSwitch;

//LED's and buttons
int pinLED = 13;
int pinButtonOn = A0; //analog  //to start the cycle
int pinButtonReset = A1; //analog   //to reset the whole cycle
int treshholdReset = 500;
int valueReset;
bool resetEnabled = false;
int tressholdStart = 500;
bool startButtonPressed = false;
int valueButtonStart;

//emergency button
int pinEmergency = A2; //analog input
bool emergencyEnabled = false;
int treshholdEmergency = 500;
int valueEmergency;

//time
unsigned long prevTime = 0;
unsigned long currentTime = millis();
int maxDurationBelt = 10000; //10 seconds max
unsigned long startTimeBelt;
int timeLimitVerInit = 100;

void setup(){

Serial.begin(9600);

//set all the pins
gripper.attach(pinGripper);   //pin to control the servomotor of the gripper

//DC motors (OUTPUTS)  //9 digital ports needed
pinMode(pinEnableVert, OUTPUT); //PWM
pinMode(pinInMotorVert1, OUTPUT);
pinMode(pinInMotorVert2, OUTPUT);
pinMode(pinEnableHor; OUTPUT); //PWM
pinMode(pinInMotorHor1, OUTPUT);
pinMode(pinInMotorHor2, OUTPUT);

//motor belt
pinMode(pinEnableBelt; OUTPUT); //PWM
pinMode(pinInMotorBelt1, OUTPUT);
pinMode(pinInMotorBelt2, OUTPUT);

//tachometer
pinMode(pinTachoHor, INPUT);
pinMode(pinTachoVer, INPUT);

//proximity sensor
pinMode(pinProximitySensor, INPUT_PULLUP);

//LED's and buttons
pinMode(pinLED, OUTPUT);

//emergency button
pinMode(pinEmergency,INPUT) //MAYBE NOT NEEDED

}

void(* resetFunc) (void) = 0;//declare reset function at address 0

void loop(){

//only during the first loop
if(firstCycle){
  //put a Lego block on the position where it can be grabbed and detect the color
  moveBeltFunction();
}
  //initialize the vertical and horizontal position, because the sensors only measure relative positions
  //initialize the vertical position
  //rack moves downwards
  analogWrite(pinEnableVer, pwmOutput); // Send PWM signal to L298N Enable pin
  digitalWrite(pinInMotorVer1, LOW); //control high and low
  digitalWrite(pinInMotorVer2, HIGH);
  LEDblink();
  currentTime = millis();
  prevTime = currentTime;
  //vertical rack moves till it goes to the end
  //loop stops when the rack doesn't move anymore, so when the tachometer does not move anymore
  counterTachVer = 0;
  while(currentTime<prevTime + timeLimitVerInit){
      valTachVer = digitalRead(pinTachoVer);
      if(prevValTachVer<valTachVer && valTachVer>treshholdTachVer){
        counterTachVer++;
        prevTime = millis();
      }
      else if(prevValTachVer>valTachVer && valTachVer<treshholdTachVer){
        counterTachVer++;
        prevTime = millis();
      }
      prevValTachVer = valTachVer;
      currentTime = millis();
    }  
    analogWrite(pinEnableVer, pwmZero); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorVer1, LOW); //control high and low
    digitalWrite(pinInMotorVer2, LOW);
    LEDshutDown();
    prevValTachVer = -1;
    counterTachVer = 0;

  //rack moves upwards
    analogWrite(pinEnableVer, pwmOutput); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorVer1, HIGH); //control high and low
    digitalWrite(pinInMotorVer2, LOW);
    LEDblink();

    counterTachVer = 0; //initialize
    while(counterTachVer<maxCountInitVer){
      valTachVer = digitalRead(pinTachoVer);
      //detect a faling or rising edge of the teeth of the tachometer
      if(prevValTachVer<valTachVer && valTachVer>treshholdTachVer){
        counterTachVer++;
      }
      else if(prevValTachVer>valTachVer && valTachVer<treshholdTachVer){
        counterTachVer++;
      }
      prevValTachVer = valTachVer;
    }
    analogWrite(pinEnableVer, pwmZero); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorVer1, LOW); //control high and low
    digitalWrite(pinInMotorVer2, LOW);
    LEDshutDown();
    counterTachVer = 0;
    prevValTachVer = -1;

  
  //initialize the horizontal position
  //go to block
  analogWrite(pinEnableHor, pwmOutput); // Send PWM signal to L298N Enable pin
  digitalWrite(pinInMotorHor1, LOW); //control high and low
  digitalWrite(pinInMotorHor2, HIGH);
  LEDblink();
  delay(delayInitHor)
  //motor stop
  analogWrite(pinEnableHor, pwmZero); // Send PWM signal to L298N Enable pin
  digitalWrite(pinInMotorHor1, LOW); //control high and low
  digitalWrite(pinInMotorHor2, LOW);
  LEDshutDown();

  //motor goes to the boxes 
  analogWrite(pinEnableHor, pwmOutput); // Send PWM signal to L298N Enable pin
  digitalWrite(pinInMotorHor1, HIGH); //control high and low
  digitalWrite(pinInMotorHor2, LOW);
  LEDblink();
  valueSwitch = analogRead(pinSwitches);
  while(valueSwitch<voltageSwitches[3]){
    valueSwitch = analogRead(pinSwitches);
  }
  //last switch is reached, now the absolute value of the robot is known
    analogWrite(pinEnableHor, pwmZero); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorHor1, LOW); //control high and low
    digitalWrite(pinInMotorHor2, LOW);
    LEDshutDown();
    
    
   valueButtonStart= analogRead(pinButtonOn);
   if(valueButtonStart>tressholdStart){
    startButtonPressed = true;
   }
   //wait till the start button is pressed
  while(!startButtonPressed){
    valueButtonStart= analogRead(pinButtonOn);
    if(valueButtonStart>tressholdStart){
     startButtonPressed = true;
   }
  }
  moveRobot = true;
  moveGlobalToBox = false;
  moveVertical = true;
  moveUp = true;
  
  firstCycle = false;
}

//Go to block

//function used when the gripper has to find the block  and go to it

if(moveRobot && !moveGlobalToBox){
//Move vertically upwards
if(moveVertical && moveUp){
  //use DC motor to go upwards
  //+check when you reach the “top”
  reached = moveVerticalFunction(upDirection);
  if(reached){
    moveVertical = false;
    moveHorizontal = true;
    moveToBox = false;
  }
}

//Move horizontally towards the blocks
if(moveHorizontal && !moveToBox){
  //use DC motor to go to the block
  //+check when you are above the block
  reached = moveHorizontalFunction(blockDirection);
  if(reached){
    moveHorizontal = false;
    moveVertical = true;
    moveUp = false;
  }
}

//Move vertically downwards
if(moveVertical && !moveUp){
  //use DC motor to go downwards
  //+check when you are at the block
  reached = moveVerticalFunction(downDirection);
  if(reached){
    moveVertical = false;
    moveRobot = false;
    gripperWorks = true;
    grab = true;
}
}
}
//Go to boxes

//The robot has to find the right box and go to it

if(moveRobot && moveGlobalToBox){

//Move vertically upwards
//+controlBelt when the gripper is fully up
//+detect next color (maybe we need an array of the colors in the queue)
if(moveVertical && moveUp){
  //use DC motor to go upwards
  //+check when you reach the “top”
  reached = moveVerticalFunction(upDirection);
  if(reached){
    moveVertical = false;
    moveRobot = false;
    moveBelt = true;
  }
}

//Move horizontally towards the boxes
if(moveHorizontal && moveToBox){
  //use DC motor to go to the block
//+check when you are above the block
  reached = moveHorizontalFunction(boxDirection);
  if(reached){
    moveHorizontal = false;
    moveVertical = true;
    moveUp = false;
  }
}

//Move vertically downwards
if(moveVertical && !moveUp){
  //use DC motor to go downwards
  //+check when you are at the block (How do we check? Ultrasonic sensor?)
  reached = moveVerticalFunction(downDirection);
  if(reached){
    moveVertical = false;
    moveRobot = false;
    gripperWorks = true;
    grab = false;
  }
}
}
//Grab the the block or open the gripper

//the robot has to grab the robot and we assume that the robot is already at the block in position to grab it or it has to put the block in the box by opening the gripper

if(gripperWorks){
  if(grab){
    reached = moveGripperFunction(gripperClosing);
    if(reached){
      gripperWorks = false;
      moveRobot = true;
      moveGlobalToBox = true;
      moveVertical = true;
      moveUp = true;
    }
  }
  if(!grab){
    reached = moveGripperFunction(gripperOpening);
    if(reached){
      gripperWorks = false;
      moveRobot = true;
      moveGlobalToBox = false;
      moveVertical = true;
      moveUp = true;
    }
  }
}
//Belt is working

//belt has to work when a block is grabbed and taken away
if(moveBelt){
  reached = moveBeltFunction();
  if(reached){
    //detect the color of the next block (maybe stack in an array)
    
    moveBelt = false;
    moveRobot = true;
    moveGlobalToBox = true;
    moveHorizontal = true;
    moveToBox = true;
  }
}
}

//Functions

//Define “global” functions that will be used in different “paragraphs”

bool moveVerticalFunction(int directionVer ){
//direction is positive if it moves upwards and negative if it moves downwards
// the output is a boolean that says if his task is finished (robot reached his final position)

if(directionVer>0){
  //action on the dc motor
    analogWrite(pinEnableVer, pwmOutput); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorVer1, HIGH); //control high and low
    digitalWrite(pinInMotorVer2, LOW);
    LEDblink();
    counterTachVer = 0; //initialize
    while(counterTachVer<maxCountTachVer){
      emergencyControl(); //control if the emergency button was pressed
      resetControl(); // control if the reset button was pressed
      valTachVer = digitalRead(pinTachoVer);
      //detect a faling or rising edge of the teeth of the tachometer
      if(prevValTachVer<valTachVer && valTachVer>treshholdTachVer){
        counterTachVer++;
      }
      else if(prevValTachVer>valTachVer && valTachVer<treshholdTachVer){
        counterTachVer++;
      }
      prevValTachVer = valTachVer;
    }
    emergencyControl(); //control if the emergency button was pressed
    resetControl(); // control if the reset button was pressed
    analogWrite(pinEnableVer, pwmZero); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorVer1, LOW); //control high and low
    digitalWrite(pinInMotorVer2, LOW);
    LEDshutDown();
    counterTachVer = 0;
    prevValTachVer = -1;
  
}
else if(directionVer<0){
  analogWrite(pinEnableVer, pwmOutput); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorVer1, LOW); //control high and low
    digitalWrite(pinInMotorVer2, HIGH);
    LEDblink();
    counterTachVer = 0; //initialize
    while(counterTachVer<maxCountTachVer){
      emergencyControl(); //control if the emergency button was pressed
      resetControl(); // control if the reset button was pressed
      valTachVer = digitalRead(pinTachoVer);
      //detect a faling or rising edge of the teeth of the tachometer
      if(prevValTachVer<valTachVer && valTachVer>treshholdTachVer){
        counterTachVer++;
      }
      else if(prevValTachVer>valTachVer && valTachVer<treshholdTachVer){
        counterTachVer++;
      }
      prevValTachVer = valTachVer;
    }
    emergencyControl(); //control if the emergency button was pressed
    resetControl(); // control if the reset button was pressed
    analogWrite(pinEnableVer, pwmZero); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorVer1, LOW); //control high and low
    digitalWrite(pinInMotorVer2, LOW);
    LEDshutDown();
    counterTachVer = 0;
    prevValTachVer = -1;
}
Serial.print("Vertical ");
Serial.print("up ");
Serial.println(directionVer);
return true; //go back to the main loop
}

bool moveHorizontalFunction(int directionHor ){
//direction is positive if it moves to the boxes and negative if it moves to the blocks
// the output is a boolean that says if his task is finished (robot reached his final position)
distanceHor = measureUltrasonic("Hor")
if(directionHor>0){
  analogWrite(pinEnableHor, pwmOutput); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorHor1, HIGH); //control high and low
    digitalWrite(pinInMotorHor2, LOW);
    LEDblink();

  counterTachHor = 0; //initialize
  maxCountTachHor = numberOfDetectionsPerCycleHor*distances[currentColor]/diameterHor/3.1415; //number of edges that the tacho has to detect till the target
    while(counterTachHor<maxCountTachHor){
      emergencyControl(); //control if the emergency button was pressed
      resetControl(); // control if the reset button was pressed
      valTachHor = digitalRead(pinTachoHor);
      //detect a faling or rising edge of the teeth of the tachometer
      if(prevValTachHor<valTachHor && valTachHor>treshholdTachHor){
        counterTachHor++;
      }
      else if(prevValTachHor>valTachHor && valTachHor<treshholdTachHor){
        counterTachHor++;
      }
      prevValTachHor = valTachHor;
    }
    emergencyControl(); //control if the emergency button was pressed
    resetControl(); // control if the reset button was pressed
    //slow down
    analogWrite(pinEnableVer, pwmSlow); // Send PWM signal to L298N Enable pin
    counterTachVer = 0;
    prevValTachVer = -1;
    //detect when we are at the right switch
    valueSwitch = analogRead(pinSwitches);
    while(valueSwitch<voltageSwitches[currentColor]){
      valueSwitch = analogRead(pinSwitches);
    }
    analogWrite(pinEnableVer, pwmZero);
    digitalWrite(pinInMotorVer1, LOW); //control high and low
    digitalWrite(pinInMotorVer2, LOW);
    LEDshutDown();
    
}
else if(directionHor<0){
  analogWrite(pinEnableHor, pwmOutput); // Send PWM signal to L298N Enable pin
    digitalWrite(pinInMotorHor1, LOW); //control high and low
    digitalWrite(pinInMotorHor2, HIGH);
    LEDblink();

 counterTachHor = 0; //initialize
  maxCountTachHor = numberOfDetectionsPerCycleHor*distances[currentColor]/diameterHor/3.1415; //number of edges that the tacho has to detect till the target
    while(counterTachHor<maxCountTachHor){
      emergencyControl(); //control if the emergency button was pressed
      resetControl(); // control if the reset button was pressed
      valTachHor = digitalRead(pinTachoHor);
      //detect a faling or rising edge of the teeth of the tachometer
      if(prevValTachHor<valTachHor && valTachHor>treshholdTachHor){
        counterTachHor++;
      }
      else if(prevValTachHor>valTachHor && valTachHor<treshholdTachHor){
        counterTachHor++;
      }
      prevValTachHor = valTachHor;
    }
    emergencyControl(); //control if the emergency button was pressed
    resetControl(); // control if the reset button was pressed
    counterTachVer = 0;
    prevValTachVer = -1;
    analogWrite(pinEnableVer, pwmZero);
    digitalWrite(pinInMotorVer1, LOW); //control high and low
    digitalWrite(pinInMotorVer2, LOW);
    LEDshutDown();
}

Serial.print("Horizontal ");
Serial.print("to Box ");
Serial.println(directionHor);
return true; //go back to the main loop
}

bool moveGripperFunction(int directionGripper ){
//the servomotor has to open or close
//it opens when direction is positive and closes when it’s negative
// the output is a boolean that says if his task is finished (gripper reached his final position)
//pay attention on how the servomotor was placed: it will affect how the angle will be defined
if(directionGripper<0){
  //gripper closing
  LEDblink();
  for(int angle = angleLow; angle<angleHigh; angle++){
    emergencyControl(); // control if the emergency button was pressed
    resetControl(); // control if the reset button was pressed
    gripper.write(angle);
    delay(delayGripper);
    
  }
  LEDshutDown();
}
else if(directionGripper>0){
  //gripper opening
  LEDblink();
  for(int angle = angleHigh; angle>angleHigh; angle--){
    emergencyControl(); // control if the emergency button was pressed
    resetControl(); // control if the reset button was pressed
    gripper.write(angle);
    delay(delayGripper);
  }
  LEDshutDown();
}
Serial.print("Gripper ");
Serial.print("opens ");
Serial.println(directionGripper);
return true; //go back to the main loop
}

bool moveBeltFunction(){
//DC motors work till the proximity sensor detects the next block
// the output is a boolean that says if his task is finished (next block is at the right position)
Serial.println("Belt");
//let the motor work
analogWrite(pinEnableBelt, pwmOutput);
digitalWrite(pinInMotorBelt1, HIGH); // pay attention to the direction of rotation of the motor
digitalWrite(pinInMotorBelt2, LOW);
LEDblink();
startTimeBelt = millis();
boolean detected = detectProximity();
while(detect==false){
  //action on dc motor
  emergencyControl(); // control if the emergency button was pressed
  resetControl(); // control if the reset button was pressed
  timeControl(startTimeBelt);
  detected = detectProximity(); //control if the proximity sensor detected a Lego block
}
//stop belt
emergencyControl(); // control if the emergency button was pressed
resetControl(); // control if the reset button was pressed
delay(delayStopBelt) //don't stop the belt immediately to put the color sensor in the center of the Lego block
//we are blind for the two buttons during this delay

emergencyControl(); // control if the emergency button was pressed
resetControl(); // control if the reset button was pressed
analogWrite(pinEnableBelt, pwmZero);
digitalWrite(pinInMotorBelt1, LOW);
digitalWrite(pinInMotorBelt2, LOW);
LEDshutDown();
//detect the color
detectColor();
emergencyControl(); // control if the emergency button was pressed
resetControl(); // control if the reset button was pressed

//put the block at the end of the belt to be able to grab the block
//enable again the motor
analogWrite(pinEnableBelt, pwmOutput);
digitalWrite(pinInMotorBelt1, HIGH);
digitalWrite(pinInMotorBelt2, LOW);
LEDblink();
emergencyControl(); // control if the emergency button was pressed
resetControl(); // control if the reset button was pressed
delay(delaySecondWorkBelt)
//we are blind for the two buttons during this delay

emergencyControl(); // control if the emergency button was pressed
resetControl(); // control if the reset button was pressed
//stop the motor again
analogWrite(pinEnableBelt, pwmZero);
digitalWrite(pinInMotorBelt1, LOW);
digitalWrite(pinInMotorBelt2, LOW);
LEDshutDown();

return true; //go back to the main loop
}

//control if the Lego block is detected by the proximity sensor
boolean detectProximity(){
  detectionProximity = =digitalRead(pinProximitySensor);
  boolean detected = false;
  if(detectionProximity == 0){
    detected = true;
  }
  return detected;
}

//must detect the color and then depending on the color, the robot knows to which box it has to go
void detectColor(){
  //initialize the variables needed for the color sensor
  uint16_t r, g, b, c, colorTemp, lux;
  tcs.getRawData(&r, &g, &b, &c);  //gives the red, green and blue color
  //grey block
  if(r>limitColor && g>limitColor && b>limitColor){
    //first box
    currentColor = followingcolor;
    followingColor = 1;
  }
  //red block
  else if(r>limitColor){
    //second box
    currentColor = followingcolor;
    followingColor = 2;
  }
  //green block
  else{
    //third block
    currentColor = followingcolor;
    followingColor = 3;
  }
}

//control if the emergency button was pressed
void emergencyControl(){
  valueEmergency = analogRead(pinEmergency);
  if(valueEmergency>treshholdEmergency){
    emergencyEnabled = true;
  }
  
  //stay in this while loop till the emergency button is released
  //when it is released, the code will go back where it was
  while(emergencyEnabled){
    Serial.println("emergency enabled");
    emergencyEnabled = false;
    valueEmergency = analogRead(pinEmergency);
    if(valueEmergency>treshholdEmergency){
      emergencyEnabled = true;
  }
  Serial.println("emergency disabled");
}

//control if the reset button is pressed
void resetControl(){
  valueReset = analogRead(pinButtonReset);
  if(valueReset>treshholdReset){
    resetEnabled = true;
    resetFunc(); //call reset 
  }
}

void timeControl(unsigned long startBelt){
  currentTime = millis();
  if(startBelt + maxDurationBelt>= currentTime){
    Serial.println("Belt took too much time");
    Serial.println("User has to take action and afterwards restart the code");
    while(1){
      //code stays stuch here because there is a problem with the belt and the Lego blocks
    }
  }
}

void LEDblink(){
  digitalWrite(pinLED, HIGH);
}

void LEDshutDown(){
  digitalWrite(pinLED,LOW);
}
